pub struct AdjacencyDataset { /* private fields */ }Implementations
Sourceimpl AdjacencyDataset
impl AdjacencyDataset
pub fn new( base_uri: &str, edge_type: &str, label: &str, direction: &str, ) -> Self
pub async fn open(&self) -> Result<Arc<Dataset>>
pub async fn open_at(&self, version: Option<u64>) -> Result<Arc<Dataset>>
pub fn get_arrow_schema(&self) -> Arc<ArrowSchema>
pub async fn read_adjacency( &self, vid: Vid, ) -> Result<Option<(Vec<Vid>, Vec<Eid>)>>
pub async fn read_adjacency_at( &self, vid: Vid, version: Option<u64>, ) -> Result<Option<(Vec<Vid>, Vec<Eid>)>>
Sourcepub async fn read_adjacency_lancedb(
&self,
store: &LanceDbStore,
vid: Vid,
) -> Result<Option<(Vec<Vid>, Vec<Eid>)>>
pub async fn read_adjacency_lancedb( &self, store: &LanceDbStore, vid: Vid, ) -> Result<Option<(Vec<Vid>, Vec<Eid>)>>
Read adjacency data for a vertex from LanceDB.
Returns None if the table doesn’t exist or no data for the vertex.
Sourcepub async fn read_adjacency_lancedb_batch(
&self,
store: &LanceDbStore,
vids: &[Vid],
) -> Result<HashMap<Vid, (Vec<Vid>, Vec<Eid>)>>
pub async fn read_adjacency_lancedb_batch( &self, store: &LanceDbStore, vids: &[Vid], ) -> Result<HashMap<Vid, (Vec<Vid>, Vec<Eid>)>>
Read adjacency data for multiple vertices in a single batch query.
Returns a HashMap mapping each vid to its (neighbors, edge_ids). VIDs with no adjacency data will not be in the map.
Sourcepub async fn open_lancedb(&self, store: &LanceDbStore) -> Result<Table>
pub async fn open_lancedb(&self, store: &LanceDbStore) -> Result<Table>
Open an adjacency table using LanceDB.
Sourcepub async fn open_or_create_lancedb(
&self,
store: &LanceDbStore,
) -> Result<Table>
pub async fn open_or_create_lancedb( &self, store: &LanceDbStore, ) -> Result<Table>
Open or create an adjacency table using LanceDB.
Sourcepub async fn write_chunk_lancedb(
&self,
store: &LanceDbStore,
batch: RecordBatch,
) -> Result<Table>
pub async fn write_chunk_lancedb( &self, store: &LanceDbStore, batch: RecordBatch, ) -> Result<Table>
Write a chunk to a LanceDB adjacency table.
Creates the table if it doesn’t exist, otherwise appends to it.
Sourcepub fn lancedb_table_name(&self) -> String
pub fn lancedb_table_name(&self) -> String
Get the LanceDB table name for this adjacency dataset.
Sourcepub async fn replace_lancedb(
&self,
store: &LanceDbStore,
batch: RecordBatch,
) -> Result<Table>
pub async fn replace_lancedb( &self, store: &LanceDbStore, batch: RecordBatch, ) -> Result<Table>
Replace an adjacency table’s contents using LanceDB atomically.
This uses a staging table for crash-safe replacement. Used by compaction to rewrite the table with merged data.