pub struct MainEdgeDataset { /* private fields */ }Expand description
Main edge dataset for the unified edges table.
This table contains all edges regardless of type, providing:
- Fast ID-based lookups without knowing the edge type
- Unified traversal queries
Implementations
Sourceimpl MainEdgeDataset
impl MainEdgeDataset
Sourcepub fn get_arrow_schema() -> Arc<ArrowSchema>
pub fn get_arrow_schema() -> Arc<ArrowSchema>
Get the Arrow schema for the main edges table.
Sourcepub fn table_name() -> &'static str
pub fn table_name() -> &'static str
Get the table name for the main edges table.
Sourcepub fn build_record_batch(
edges: &[(Eid, Vid, Vid, String, Properties, bool, u64)],
created_at: Option<&HashMap<Eid, i64>>,
updated_at: Option<&HashMap<Eid, i64>>,
) -> Result<RecordBatch>
pub fn build_record_batch( edges: &[(Eid, Vid, Vid, String, Properties, bool, u64)], created_at: Option<&HashMap<Eid, i64>>, updated_at: Option<&HashMap<Eid, i64>>, ) -> Result<RecordBatch>
Build a record batch for the main edges table.
Arguments
edges- List of (eid, src_vid, dst_vid, edge_type, properties, deleted, version) tuplescreated_at- Optional map of Eid -> nanoseconds since epochupdated_at- Optional map of Eid -> nanoseconds since epoch
Sourcepub async fn write_batch_lancedb(
store: &LanceDbStore,
batch: RecordBatch,
) -> Result<Table>
pub async fn write_batch_lancedb( store: &LanceDbStore, batch: RecordBatch, ) -> Result<Table>
Write a batch to the main edges table.
Creates the table if it doesn’t exist, otherwise appends to it.
Sourcepub async fn ensure_default_indexes_lancedb(table: &Table) -> Result<()>
pub async fn ensure_default_indexes_lancedb(table: &Table) -> Result<()>
Ensure default indexes exist on the main edges table.
Sourcepub async fn find_by_eid(
store: &LanceDbStore,
eid: Eid,
) -> Result<Option<(Vid, Vid, String, Properties)>>
pub async fn find_by_eid( store: &LanceDbStore, eid: Eid, ) -> Result<Option<(Vid, Vid, String, Properties)>>
Query the main edges table for an edge by eid.
Sourcepub async fn open_table(store: &LanceDbStore) -> Result<Option<Table>>
pub async fn open_table(store: &LanceDbStore) -> Result<Option<Table>>
Open the main edges table.
Returns None if the table doesn’t exist yet.
Sourcepub async fn find_all_eids(store: &LanceDbStore) -> Result<Vec<Eid>>
pub async fn find_all_eids(store: &LanceDbStore) -> Result<Vec<Eid>>
Find all non-deleted EIDs from the main edges table.
Sourcepub async fn find_eids_by_type_name(
store: &LanceDbStore,
type_name: &str,
) -> Result<Vec<Eid>>
pub async fn find_eids_by_type_name( store: &LanceDbStore, type_name: &str, ) -> Result<Vec<Eid>>
Find EIDs by type name in the main edges table.
Sourcepub async fn find_props_by_eid(
store: &LanceDbStore,
eid: Eid,
) -> Result<Option<Properties>>
pub async fn find_props_by_eid( store: &LanceDbStore, eid: Eid, ) -> Result<Option<Properties>>
Find properties for an edge by EID in the main edges table.
Returns the props_json parsed into a Properties HashMap if found. This is used as a fallback for unknown/schemaless edge types.
Sourcepub async fn find_type_by_eid(
store: &LanceDbStore,
eid: Eid,
) -> Result<Option<String>>
pub async fn find_type_by_eid( store: &LanceDbStore, eid: Eid, ) -> Result<Option<String>>
Find edge type name by EID in the main edges table.
Sourcepub async fn find_edges_by_type_name(
store: &LanceDbStore,
type_name: &str,
) -> Result<Vec<(Eid, Vid, Vid, Properties)>>
pub async fn find_edges_by_type_name( store: &LanceDbStore, type_name: &str, ) -> Result<Vec<(Eid, Vid, Vid, Properties)>>
Find edge data (eid, src_vid, dst_vid, props) by type name in the main edges table.
Returns all non-deleted edges with the given type name.
Sourcepub async fn find_edges_by_type_names(
store: &LanceDbStore,
type_names: &[&str],
) -> Result<Vec<(Eid, Vid, Vid, String, Properties)>>
pub async fn find_edges_by_type_names( store: &LanceDbStore, type_names: &[&str], ) -> Result<Vec<(Eid, Vid, Vid, String, Properties)>>
Find edge data (eid, src_vid, dst_vid, edge_type, props) by multiple type names in the main edges table.
Returns all non-deleted edges with any of the given type names.
This is used for OR relationship type queries like [:KNOWS|HATES].