pub struct AdjacencyDataset { /* private fields */ }Implementations
Sourceimpl AdjacencyDataset
impl AdjacencyDataset
Sourcepub fn new(
_base_uri: &str,
edge_type: &str,
_label: &str,
direction: &str,
) -> Self
pub fn new( _base_uri: &str, edge_type: &str, _label: &str, direction: &str, ) -> Self
Construct a primary (unbranched) adjacency dataset handle.
The on-disk dataset is per-(edge_type, direction) — the label
argument is vestigial (adjacency is not per-label) and kept only for
Sourcepub fn new_branched(
base_uri: &str,
edge_type: &str,
label: &str,
direction: &str,
branch: impl Into<String>,
) -> Self
pub fn new_branched( base_uri: &str, edge_type: &str, label: &str, direction: &str, branch: impl Into<String>, ) -> Self
Construct an adjacency dataset that reads from a Lance branch.
pub fn get_arrow_schema(&self) -> Arc<ArrowSchema> ⓘ
Sourcepub async fn read_adjacency_backend(
&self,
backend: &dyn StorageBackend,
vid: Vid,
) -> Result<Option<(Vec<Vid>, Vec<Eid>)>>
pub async fn read_adjacency_backend( &self, backend: &dyn StorageBackend, vid: Vid, ) -> Result<Option<(Vec<Vid>, Vec<Eid>)>>
Read adjacency data for a vertex from the storage backend.
Returns None if the table doesn’t exist or no data for the vertex.
Sourcepub async fn read_adjacency_backend_batch(
&self,
backend: &dyn StorageBackend,
vids: &[Vid],
) -> Result<HashMap<Vid, (Vec<Vid>, Vec<Eid>)>>
pub async fn read_adjacency_backend_batch( &self, backend: &dyn StorageBackend, vids: &[Vid], ) -> Result<HashMap<Vid, (Vec<Vid>, Vec<Eid>)>>
Read adjacency data for multiple vertices in a single batch query.
Returns a HashMap mapping each vid to its (neighbors, edge_ids). VIDs with no adjacency data will not be in the map.
Sourcepub async fn open_or_create(&self, backend: &dyn StorageBackend) -> Result<()>
pub async fn open_or_create(&self, backend: &dyn StorageBackend) -> Result<()>
Open or create an adjacency table via the storage backend.
Sourcepub async fn write_chunk(
&self,
backend: &dyn StorageBackend,
batch: RecordBatch,
) -> Result<()>
pub async fn write_chunk( &self, backend: &dyn StorageBackend, batch: RecordBatch, ) -> Result<()>
Write a chunk to an adjacency table.
Creates the table if it doesn’t exist, otherwise appends to it.
Sourcepub fn table_name(&self) -> String
pub fn table_name(&self) -> String
Get the table name for this adjacency dataset.
Sourcepub async fn replace(
&self,
backend: &dyn StorageBackend,
batch: RecordBatch,
) -> Result<()>
pub async fn replace( &self, backend: &dyn StorageBackend, batch: RecordBatch, ) -> Result<()>
Replace an adjacency table’s contents atomically.
Used by compaction to rewrite the table with merged data.